==> atlassian-mail-7.0.4-sources.jar: com/atlassian/mail/server/impl/util/MessageCreator.java <==
package com.atlassian.mail.server.impl.util;

import com.atlassian.mail.Email;
import com.atlassian.mail.MailException;
import com.atlassian.mail.MailUtils;
import org.apache.commons.lang3.StringUtils;

import javax.mail.MessagingException;
import javax.mail.Multipart;
import javax.mail.Part;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeBodyPart;
import javax.mail.internet.MimeMessage;
import java.io.UnsupportedEncodingException;
import java.util.Calendar;
import java.util.Iterator;
import java.util.Map;

public class MessageCreator {
    public void updateMimeMessage(Email email, String defaultFrom, String prefix, MimeMessage message) throws MailException, MessagingException, UnsupportedEncodingException {
        String from = StringUtils.trim(email.getFrom());
        String fromName = email.getFromName();
        String to = email.getTo();
        String cc = email.getCc();
        String bcc = email.getBcc();
        String replyTo = email.getReplyTo();
        String inReplyTo = email.getInReplyTo();
        String subject = email.getSubject();
        String body = email.getBody();
        String mimeType = email.getMimeType();
        String encoding = email.getEncoding();
        Map headers = email.getHeaders();
        Multipart multipart = email.getMultipart();

        if (StringUtils.isBlank(StringUtils.trim(to)) && StringUtils.isBlank(StringUtils.trim(cc)) && StringUtils.isBlank(StringUtils.trim(bcc))) {
            throw new MailException("Tried to send mail (" + subject + ") with no recipients.");
        }

        message.setSentDate(Calendar.getInstance().getTime());
        if (to != null)
            message.setRecipients(javax.mail.Message.RecipientType.TO, MailUtils.parseAddresses(to));

        if (cc != null)
            message.setRecipients(javax.mail.Message.RecipientType.CC, MailUtils.parseAddresses(cc));

        if (bcc != null)
            message.setRecipients(javax.mail.Message.RecipientType.BCC, MailUtils.parseAddresses(bcc));

        if (replyTo != null)
            message.setReplyTo(MailUtils.parseAddresses(replyTo));

        if (inReplyTo != null)
            message.setHeader("In-Reply-To", inReplyTo);

        if (StringUtils.isNotBlank(from)) {
            message.setFrom(buildFromFieldAsInternetAddress(from, fromName, encoding));
        } else if (StringUtils.isNotBlank(defaultFrom)) {
            message.setFrom(buildFromFieldAsInternetAddress(defaultFrom, fromName, encoding));
        } else {
            throw new MailException("Tried to send mail (" + subject + ") from no one (no 'from' and 'default from' specified).");
        }

        String fullSubject = subject;
        if (shouldIncludeSubjectPrefix(prefix, email))
            fullSubject = prefix + " " + fullSubject;

        if (encoding != null)
            message.setSubject(fullSubject, encoding);
        else
            message.setSubject(fullSubject);

        String mimeTypeAndEncoding = mimeType;

        if (encoding != null)
            mimeTypeAndEncoding += "; charset=" + encoding + "";

        if (multipart != null) {
            // Create a MimeBodyPart for the body
            if (StringUtils.isNotBlank(body)) {
                MimeBodyPart messageBodyPart = new MimeBodyPart();
                messageBodyPart.setContent(body, mimeTypeAndEncoding);
                messageBodyPart.setDisposition(Part.INLINE);
                // add to multipart passed in
                multipart.addBodyPart(messageBodyPart, 0);
            }

            message.setContent(multipart);
        } else {
            message.setContent(body, mimeTypeAndEncoding);
        }

        // Add the custom headers (if any)
        if (headers != null) {
            for (Iterator iterator = headers.entrySet().iterator(); iterator.hasNext(); ) {
                Map.Entry entry = (Map.Entry) iterator.next();
                message.addHeader((String) entry.getKey(), (String) entry.getValue());
            }
        }
    }

    private boolean shouldIncludeSubjectPrefix(String prefix, Email email) {
        return !email.isExcludeSubjectPrefix() && StringUtils.isNotBlank(prefix);
    }

    private InternetAddress buildFromFieldAsInternetAddress(
            String fromAddress,
            String fromName,
            String encoding
    ) throws MailException, MessagingException, UnsupportedEncodingException {
        InternetAddress internetAddress = new InternetAddress(fromAddress);
        // Checks if the email address has a personal name attached to it and if not, uses the provided fromName
        if (StringUtils.isNotBlank(fromName) && internetAddress.getPersonal() == null) {
            if (encoding != null) {
                internetAddress.setPersonal(fromName, encoding);
            } else {
                internetAddress.setPersonal(fromName);
            }
        }

        return internetAddress;
    }
}

==> atlassian-mail-7.0.7-sources.jar: com/atlassian/mail/server/impl/util/MessageCreator.java <==
package com.atlassian.mail.server.impl.util;

import java.io.UnsupportedEncodingException;
import java.util.Calendar;
import java.util.Iterator;
import java.util.Map;
import javax.mail.MessagingException;
import javax.mail.Multipart;
import javax.mail.Part;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeBodyPart;
import javax.mail.internet.MimeMessage;

import org.apache.commons.lang3.StringUtils;

import com.atlassian.mail.Email;
import com.atlassian.mail.MailException;
import com.atlassian.mail.MailUtils;

public class MessageCreator {
    /**
     * @deprecated since 7.1.0. Use {@link #updateMimeMessage(Email, String, String, String, MimeMessage)} instead.
     */
    @Deprecated
    public void updateMimeMessage(Email email, String defaultFrom, String prefix, MimeMessage message)
            throws MailException, MessagingException, UnsupportedEncodingException {
        this.updateMimeMessage(email, defaultFrom, null, prefix, message);
    }

    public void updateMimeMessage(
            Email email, String defaultFrom, String defaultReplyTo, String prefix, MimeMessage message)
            throws MailException, MessagingException, UnsupportedEncodingException {
        String from = StringUtils.trim(email.getFrom());
        String fromName = email.getFromName();
        String to = email.getTo();
        String cc = email.getCc();
        String bcc = email.getBcc();
        String replyTo = email.getReplyTo();
        String inReplyTo = email.getInReplyTo();
        String subject = email.getSubject();
        String body = email.getBody();
        String mimeType = email.getMimeType();
        String encoding = email.getEncoding();
        Map headers = email.getHeaders();
        Multipart multipart = email.getMultipart();

        if (StringUtils.isBlank(StringUtils.trim(to))
                && StringUtils.isBlank(StringUtils.trim(cc))
                && StringUtils.isBlank(StringUtils.trim(bcc))) {
            throw new MailException("Tried to send mail (" + subject + ") with no recipients.");
        }

        message.setSentDate(Calendar.getInstance().getTime());
        if (to != null) message.setRecipients(javax.mail.Message.RecipientType.TO, MailUtils.parseAddresses(to));

        if (cc != null) message.setRecipients(javax.mail.Message.RecipientType.CC, MailUtils.parseAddresses(cc));

        if (bcc != null) message.setRecipients(javax.mail.Message.RecipientType.BCC, MailUtils.parseAddresses(bcc));

        if (replyTo != null) {
            message.setReplyTo(MailUtils.parseAddresses(replyTo));
        } else if (StringUtils.isNotBlank(defaultReplyTo)) {
            message.setReplyTo(MailUtils.parseAddresses(defaultReplyTo));
        }

        if (inReplyTo != null) message.setHeader("In-Reply-To", inReplyTo);

        if (StringUtils.isNotBlank(from)) {
            message.setFrom(buildFromFieldAsInternetAddress(from, fromName, encoding));
        } else if (StringUtils.isNotBlank(defaultFrom)) {
            message.setFrom(buildFromFieldAsInternetAddress(defaultFrom, fromName, encoding));
        } else {
            throw new MailException(
                    "Tried to send mail (" + subject + ") from no one (no 'from' and 'default from' specified).");
        }

        String fullSubject = subject;
        if (shouldIncludeSubjectPrefix(prefix, email)) fullSubject = prefix + " " + fullSubject;

        if (encoding != null) message.setSubject(fullSubject, encoding);
        else message.setSubject(fullSubject);

        String mimeTypeAndEncoding = mimeType;

        if (encoding != null) mimeTypeAndEncoding += "; charset=" + encoding + "";

        if (multipart != null) {
            // Create a MimeBodyPart for the body
            if (StringUtils.isNotBlank(body)) {
                MimeBodyPart messageBodyPart = new MimeBodyPart();
                messageBodyPart.setContent(body, mimeTypeAndEncoding);
                messageBodyPart.setDisposition(Part.INLINE);
                // add to multipart passed in
                multipart.addBodyPart(messageBodyPart, 0);
            }

            message.setContent(multipart);
        } else {
            message.setContent(body, mimeTypeAndEncoding);
        }

        // Add the custom headers (if any)
        if (headers != null) {
            for (Iterator iterator = headers.entrySet().iterator(); iterator.hasNext(); ) {
                Map.Entry entry = (Map.Entry) iterator.next();
                message.addHeader((String) entry.getKey(), (String) entry.getValue());
            }
        }
    }

    private boolean shouldIncludeSubjectPrefix(String prefix, Email email) {
        return !email.isExcludeSubjectPrefix() && StringUtils.isNotBlank(prefix);
    }

    private InternetAddress buildFromFieldAsInternetAddress(String fromAddress, String fromName, String encoding)
            throws MessagingException, UnsupportedEncodingException {
        InternetAddress internetAddress = new InternetAddress(fromAddress);
        // Checks if the email address has a personal name attached to it and if not, uses the provided fromName
        if (StringUtils.isNotBlank(fromName) && internetAddress.getPersonal() == null) {
            if (encoding != null) {
                internetAddress.setPersonal(fromName, encoding);
            } else {
                internetAddress.setPersonal(fromName);
            }
        }

        return internetAddress;
    }
}
